import React from 'react';

type IconStyles = 'home' | 'menu' | 'menu_open' | 'monitoring' | 'palette' | 'info' | 'search' | 'cancel' | 'login' | 'logout' | 'add' | 'remove' | 'close' | 'list' | 'construction' | 'work' | 'arrow_back' | 'arrow_forward' | string;
type IconColors = 'primary' | 'on-primary-container' | 'on-surface-variant';

interface IconProps {
    icon: IconStyles;
    color?: IconColors;
    onClick?: Function;
}
declare function Icon(props: IconProps): React.JSX.Element;

type ButtonVariants = 'filled' | 'elevated' | 'tonal' | 'outlined' | 'text' | 'title';

interface ButtonProps {
    variant?: ButtonVariants;
    text: string;
    onClick: React.MouseEventHandler;
    icon?: IconStyles;
    iconOnly?: boolean;
    disabled?: boolean;
    style?: React.CSSProperties;
}
declare function Button(props: ButtonProps): React.JSX.Element;

type DialogSizes = 'small' | 'medium' | 'large';

interface DialogProps extends React.HTMLProps<HTMLDivElement> {
    open: boolean;
    modalSize: DialogSizes;
    backgroundProps?: Partial<React.HTMLProps<HTMLDivElement>>;
}
declare const Dialog: React.ForwardRefExoticComponent<Omit<DialogProps, "ref"> & React.RefAttributes<HTMLDivElement>>;

interface DialogContentProps {
    children: React.ReactNode;
}
declare function DialogContent(props: DialogContentProps): React.JSX.Element;

interface DialogFooterProps {
    children: React.ReactNode;
}
declare function DialogFooter(props: DialogFooterProps): React.JSX.Element;

interface DialogHeaderProps {
    children: React.ReactNode;
}
declare function DialogHeader(props: DialogHeaderProps): React.JSX.Element;

interface DrawerProps {
    isOpen: boolean;
    handleCloseDrawer: React.MouseEventHandler;
    drawerContentBottom?: JSX.Element;
    drawerContentTop?: JSX.Element;
}
declare function Drawer(props: DrawerProps): React.JSX.Element;

interface DrawerItemProps {
    icon: IconStyles;
    onClick: Function;
    label?: string;
    match?: boolean;
}
declare function DrawerItem(props: DrawerItemProps): React.JSX.Element;

type LoadingSpinnerSizes = 'small' | 'large';

interface LoadingSpinnerProps {
    size: LoadingSpinnerSizes;
}
declare function LoadingSpinner(props: LoadingSpinnerProps): React.JSX.Element;

interface SideNavProps {
    topSection?: JSX.Element;
    bottomSection?: JSX.Element;
}
declare function SideNav(props: SideNavProps): React.JSX.Element;

interface SideNavItemProps {
    icon: IconStyles;
    onClick: Function;
    label?: string;
    match?: boolean;
}
declare function SideNavItem(props: SideNavItemProps): React.JSX.Element;

type TextInputStyles = 'filled' | 'outlined';
type TextInputColors = 'surface' | 'tinted-surface';

interface TextInputProps {
    id: string;
    label: string;
    value: string;
    onInput: React.FormEventHandler<HTMLInputElement>;
    inputStyle: TextInputStyles;
    background: TextInputColors;
    placeholder?: string;
    onKeyUp?: React.KeyboardEventHandler<HTMLInputElement>;
    type?: string;
    icon?: IconStyles;
    disabled?: boolean;
}
declare function TextInput(props: TextInputProps): React.JSX.Element;

interface TopNavProps {
    leftSection?: JSX.Element;
    rightSection?: JSX.Element;
}
declare function TopNav(props: TopNavProps): React.JSX.Element;

interface TopNavItemProps {
    icon: IconStyles;
    onClick: Function;
    label?: string;
    match?: boolean;
}
declare function TopNavItem(props: TopNavItemProps): React.JSX.Element;

export { Button, ButtonVariants, Dialog, DialogContent, DialogFooter, DialogHeader, Drawer, DrawerItem, Icon, IconColors, IconStyles, LoadingSpinner, LoadingSpinnerSizes, SideNav, SideNavItem, TextInput, TopNav, TopNavItem };
